@@ -10,12 +10,6 @@ const contextMenuItems = [
     { title: tr('contextMenuRequestGlobalAutoType'), action: 'request_autotype' }
 ];
 
-const menuContexts = [ 'editable' ];
-    
-if (isFirefox()) {
-    menuContexts.push('password');
-}
-
 const initListeners = async function() {
     /**
      * Generate information structure for created tab and invoke all needed
@@ -160,14 +154,19 @@ const initListeners = async function() {
     });
 };
 
-const initContextMenuItems = async function() { 
+const initContextMenuItems = async function() {
+    page.menuContexts = [ 'editable' ];
+    if (page.isFirefox) {
+        page.menuContexts.push('password');
+    }
+
     // Create context menu items
     await browser.contextMenus.removeAll();
     for (const item of contextMenuItems) {
         try {
             await browser.contextMenus.create({
                 title: item.title,
-                contexts: menuContexts,
+                contexts: page.menuContexts,
                 visible: item.visible,
                 id: item.id || item.action
             });
@@ -180,6 +179,7 @@ const initContextMenuItems = async function() {
 (async () => {
     try {
         await keepass.migrateKeyRing();
+        await page.initBrowser();
         await page.initSettings();
         await page.initSitePreferences();
         await page.initOpenedTabs();
@@ -189,7 +189,7 @@ const initContextMenuItems = async function() {
         await keepass.reconnect(null, 5000); // 5 second timeout for the first connect
         await keepass.enableAutomaticReconnect();
         await keepass.updateDatabase();
-    } catch (e) {
+    } catch (_e) {
         logError('init.js failed');
     }
 })();
