@@ -1,6 +1,7 @@
 'use strict';
 
 const EXTENSION_NAME = 'KeePassXC-Browser';
+const DEFINED_CUSTOM_FIELDS = 'defined-custom-fields';
 
 // Site Preferences ignore options
 const IGNORE_NOTHING = 'ignoreNothing';
@@ -169,10 +170,10 @@ const trimURL = function(url) {
 };
 
 const debugLogMessage = function(message, extra) {
-    console.log(`[Debug ${getFileAndLine()}] ${EXTENSION_NAME} - ${message}`);
+    console.debug(`[Debug ${getFileAndLine()}] ${EXTENSION_NAME} - ${message}`);
 
     if (extra) {
-        console.log(extra);
+        console.debug(extra);
     }
 };
 
