@@ -466,6 +466,28 @@ kpxcFields.checkExistingFields = function() {
     }
 };
 
+// Check for popup overlays
+kpxcFields.isOverlayOnTop = function(rect) {
+    for (const overlay of kpxcFields.overlays ?? []) {
+        if (kpxcSites.overlayExceptionFound(overlay)) {
+            continue;
+        }
+
+        const overlayRect = overlay?.getBoundingClientRect();
+        if (overlayRect && elementsOverlap(rect, overlayRect)) {
+            return true;
+        }
+    }
+
+    return false;
+};
+
+/**
+ * Check if element is the topmost element
+ * @param {HTMLElement} elem    Element to be checked
+ * @param {DOMRect} rect        Precalculated DOMRect of the element
+ * @returns {boolean}           True if element is the topmost
+ */
 kpxcFields.isTopElement = function(elem, rect) {
     if (!elem || !rect) {
         return false;
@@ -479,7 +501,7 @@ kpxcFields.isTopElement = function(elem, rect) {
         const topElement = rootNode.elementFromPoint(x, elementRect.top + (elementRect.height / 2));
         return element?.labels &&
             element.labels[0] === topElement &&
-            isElementInside(elementRect, topElement.getBoundingClientRect())
+            elementsOverlap(elementRect, topElement.getBoundingClientRect())
             ? element
             : topElement;
     };
@@ -493,16 +515,9 @@ kpxcFields.isTopElement = function(elem, rect) {
         return false;
     }
 
-    // Check for popup overlays
-    for (const overlay of kpxcFields.overlays ?? []) {
-        if (kpxcSites.overlayExceptionFound(overlay)) {
-            continue;
-        }
-
-        const overlayRect = overlay?.getBoundingClientRect();
-        if (overlayRect && elementsOverlap(rect, overlayRect)) {
-            return false;
-        }
+    // Check if element has an overlay
+    if (kpxcFields.isOverlayOnTop(rect)) {
+        return false;
     }
 
     return true;
@@ -573,14 +588,14 @@ kpxcFields.traverseParents = function(element, predicate, resultFn = () => true,
 kpxcFields.useCustomLoginFields = async function() {
     const location = kpxc.getDocumentLocation();
     const creds = kpxc.settings['defined-custom-fields'][location];
-    if (!creds.username && !creds.password && !creds.totp && creds.fields.length === 0) {
+    if (!creds.username && !creds.password && !creds.totp && creds.fields.length === 0 && !creds.submitButton) {
         return;
     }
 
-    // Finds the input field based on the stored ID
-    const findInputField = async function(inputFields, idArray) {
+    // Finds the element based on the stored ID
+    const findElement = async function(fields, idArray) {
         if (idArray) {
-            const input = inputFields.find(e => e === kpxcFields.getId(idArray, e));
+            const input = fields.find(e => e === kpxcFields.getId(idArray, e));
             if (input) {
                 return input;
             }
@@ -597,16 +612,24 @@ kpxcFields.useCustomLoginFields = async function() {
         }
     });
 
-    const [ username, password, totp ] = await Promise.all([
-        await findInputField(inputFields, creds.username),
-        await findInputField(inputFields, creds.password),
-        await findInputField(inputFields, creds.totp)
+    const buttons = [];
+    document.body.querySelectorAll('button, input[type=submit]').forEach(e => {
+        if (e.type !== 'hidden' && !e.disabled) {
+            buttons.push(e);
+        }
+    });
+
+    const [ username, password, totp, submitButton ] = await Promise.all([
+        await findElement(inputFields, creds.username),
+        await findElement(inputFields, creds.password),
+        await findElement(inputFields, creds.totp),
+        await findElement(buttons, creds.submitButton),
     ]);
 
     // Handle StringFields
     const stringFields = [];
     for (const sf of creds.fields) {
-        const field = await findInputField(inputFields, sf);
+        const field = await findElement(inputFields, sf);
         if (field) {
             stringFields.push(field);
         }
@@ -624,7 +647,8 @@ kpxcFields.useCustomLoginFields = async function() {
         password: password,
         passwordInputs: [ password ],
         totp: totp,
-        fields: stringFields
+        fields: stringFields,
+        submitButton: submitButton
     });
 
     return combinations;
