@@ -21,6 +21,7 @@ kpxc.databaseState = DatabaseState.DISCONNECTED;
 kpxc.detectedFields = 0;
 kpxc.improvedFieldDetectionEnabledForPage = false;
 kpxc.inputs = [];
+kpxc.isFirefox;
 kpxc.settings = {};
 kpxc.singleInputEnabledForPage = false;
 kpxc.submitUrl = null;
@@ -32,7 +33,7 @@ kpxc.addToSitePreferences = async function(optionName, addWildcard = false) {
     let site;
     try {
         site = trimURL(window.top.location.href);
-    } catch (err) {
+    } catch (_err) {
         logDebug('Adding to Site Preferences denied from iframe.');
         return;
     }
@@ -718,60 +719,6 @@ kpxc.setPasswordFilled = async function(state) {
     await sendMessage('password_set_filled', state);
 };
 
-// Special handling for setting value to select and checkbox elements
-kpxc.setValue = function(field, value, forced = false) {
-    if (field.matches('select')) {
-        value = value.toLowerCase().trim();
-        const options = field.querySelectorAll('option');
-
-        for (const o of options) {
-            if (o.textContent.toLowerCase().trim() === value) {
-                kpxc.setValueWithChange(field, o.value);
-                return false;
-            }
-        }
-
-        return;
-    } else if (field.getLowerCaseAttribute('type') === 'checkbox' && value?.toLowerCase() === 'true') {
-        field.checked = true;
-    }
-
-    // Make sure the input is not wrapped inside another element (custom INPUT element)
-    if (field?.nodeName !== 'INPUT' && field?.nodeName?.includes('INPUT')) {
-        const childInput = field?.querySelector('input');
-        const fieldsFromShadowDOM = kpxcObserverHelper.findInputsFromShadowDOM(field);
-        field = childInput ?? fieldsFromShadowDOM[0];
-    }
-
-
-    kpxc.setValueWithChange(field, value, forced);
-};
-
-// Sets a new value to input field and triggers necessary events
-kpxc.setValueWithChange = function(field, value, forced = false) {
-    if (!field || (field?.readOnly && !forced)) {
-        return;
-    }
-
-    const dispatchLegacyEvent = function(elem, eventName) {
-        const legacyEvent = elem.ownerDocument.createEvent('Event');
-        legacyEvent.initEvent(eventName, true, false);
-        elem.dispatchEvent(legacyEvent);
-    };
-
-    field.focus();
-    field.dispatchEvent(new KeyboardEvent('keydown', { bubbles: true, cancelable: false }));
-    field.dispatchEvent(new KeyboardEvent('keypress', { bubbles: true, cancelable: false }));
-    field.dispatchEvent(new KeyboardEvent('keyup', { bubbles: true, cancelable: false }));
-    field.dispatchEvent(new Event('input', { bubbles: true, cancelable: false }));
-    field.dispatchEvent(new Event('change', { bubbles: true, cancelable: false }));
-    field.value = value;
-
-    // Some pages will not accept the value change without dispatching events directly to the document
-    dispatchLegacyEvent(field, 'input');
-    dispatchLegacyEvent(field, 'change');
-};
-
 kpxc.showGroupNameInAutocomplete = function() {
     return !kpxc.settings.useCompactMode
         || (kpxc.settings.showGroupNameInAutocomplete && kpxc.getUniqueGroupCount(kpxc.credentials) > 1);
@@ -783,7 +730,7 @@ kpxc.siteIgnored = async function(condition) {
         let currentLocation;
         try {
             currentLocation = window.top.location.href;
-        } catch (err) {
+        } catch (_err) {
             // Cross-domain security error inspecting window.top.location.href.
             // This catches an error when an iframe is being accessed from another (sub)domain
             // -> use the iframe URL instead.
@@ -904,6 +851,7 @@ const initContentScript = async function() {
         }
 
         kpxc.settings = settings;
+        kpxc.isFirefox = await sendMessage('is_firefox');
 
         if (await kpxc.siteIgnored()) {
             logDebug('This site is ignored in Site Preferences.');
@@ -1050,7 +998,7 @@ const isIframeAllowed = async function() {
         // Check for Cross-domain security error when inspecting window.top.location.href
         const currentLocation = window.top.location.href;
         return true;
-    } catch (err) {
+    } catch (_err) {
         // Inspect iframe using TLD and the tab's original URL
         const allowed = await sendMessage('is_iframe_allowed', [ window.location.href, window.location.hostname ]);
         if (allowed) {
