@@ -2,6 +2,7 @@
 
 const options = {};
 options.dropdownButton = null;
+options.isFirefox = false;
 
 const $ = function(elem) {
     return document.querySelector(elem);
@@ -207,7 +208,7 @@ options.initGeneralSettings = async function() {
     });
 
     $('#configureCommands').addEventListener('click', function() {
-        if (isFirefox()) {
+        if (options.isFirefox) {
             if (typeof(browser.commands.openShortcutSettings) === 'function') {
                 browser.commands.openShortcutSettings();
             } else {
@@ -286,7 +287,7 @@ options.initGeneralSettings = async function() {
                     // Verify the import
                     temporarySettings = contents;
                     dialogImportSettingsModal.show();
-                } catch (err) {
+                } catch (_err) {
                     console.log('Error loading JSON settings file.');
                 }
             };
@@ -312,6 +313,24 @@ options.initGeneralSettings = async function() {
         }
     });
 
+    // Reset all settings modal
+    const dialogResetSettingsModal = new bootstrap.Modal('#dialogResetSettings',
+        { keyboard: true, focus: false, backdrop: true });
+
+    $('#dialogResetSettings').addEventListener('shown.bs.modal', function(modalEvent) {
+        modalEvent.currentTarget.querySelector('.modal-footer button.yes').focus();
+    });
+
+    $('#resetSettingsButton').addEventListener('click', function() {
+        dialogResetSettingsModal.show();
+    });
+
+    $('#dialogResetSettings .modal-footer button.yes').addEventListener('click', function(e) {
+        dialogResetSettingsModal.hide();
+        browser.runtime.sendMessage({ action: 'reset_all_settings' });
+        location.reload();
+    });
+
     $('#copyVersionToClipboard').addEventListener('click', function () {
         const copyText = document.getElementById('versionInfo').innerText;
         navigator.clipboard.writeText(copyText);
@@ -964,6 +983,8 @@ window.addEventListener('scroll', function() {
 
         const keyRing = await browser.runtime.sendMessage({ action: 'load_keyring' });
         options.keyRing = keyRing;
+        options.isFirefox = await browser.runtime.sendMessage({ action: 'is_firefox' });
+
         options.initMenu();
         await options.initGeneralSettings();
         options.initConnectedDatabases();
