@@ -57,6 +57,10 @@ function statusResponse(r) {
             $('#username-field-detected').show();
         }
 
+        if (r.iframeDetected) {
+            $('#iframe-detected').show();
+        }
+
         reloadCount = 0;
     }
 }
@@ -137,6 +141,12 @@ const sendMessageToTab = async function(message) {
         $('#username-field-detected').hide();
     });
 
+    $('#allow-iframe-button').addEventListener('click', async () => {
+        await sendMessageToTab('add_allow_iframes_option');
+        await sendMessageToTab('redetect_fields');
+        $('#iframe-detected').hide();
+    });
+
     $('#getting-started-alert-close-button').addEventListener('click', async () => {
         await browser.runtime.sendMessage({
             action: 'hide_getting_started_guide_alert'
