@@ -16,7 +16,8 @@ async function initSettings() {
     });
 
     const customLoginFieldsButton = document.body.querySelector('#settings #choose-custom-login-fields-button');
-    if (isFirefox()) {
+    const isFirefox = await browser.runtime.sendMessage({ action: 'is_firefox' });
+    if (isFirefox) {
         customLoginFieldsButton.id = 'choose-custom-login-fields-button-moz';
     }
 
